==> nextcloud-25.0.8.tgz: nextcloud/apps/theming/l10n/zh_CN.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "输入的名称过长",
    "The given web address is too long" : "输入的地址过长",
    "The given web address is not a valid URL" : "提供的web地址不是一个合法的URL",
    "The given legal notice address is too long" : "提供的法律通告地址太长",
    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的URL",
    "The given privacy policy address is too long" : "提供的隐私政策地址太长",
    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的URL",
    "The given slogan is too long" : "输入的标语过长",
    "The given color is invalid" : "提供的颜色无效",
    "Saved" : "已保存",
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超出了 php.ini 中的 upload_max_filesize 的值",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件超过了 HTML 表单中指定的 MAX_FILE_SIZE 指令",
    "The file was only partially uploaded" : "该文件只有部分被上传",
    "No file was uploaded" : "没有文件被上传",
    "Missing a temporary folder" : "缺少临时文件夹",
    "Could not write file to disk" : "无法写入文件到磁盘",
    "A PHP extension stopped the file upload" : "PHP 扩展停止了文件上传。",
    "No file uploaded" : "文件没有上传",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "你已经在使用一个自定义的主题。主题应用的设置可能会被其覆盖。",
    "Theming" : "主题",
    "Appearance and accessibility" : "外观和可访问性",
    "Dark theme with high contrast mode" : "高对比度深色主题",
    "Enable dark high contrast mode" : "使用深色高对比度模式",
    "Similar to the high contrast mode, but with dark colours." : "类似高对比度模式，但是使用深色色调。",
    "Dark theme" : "深色主题",
    "Enable dark theme" : "启用深色主题",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "降低整体亮度以缓解视疲劳的深色主题。",
    "System default theme" : "系统默认主题",
    "Enable the system default" : "使用系统默认主题",
    "Using the default system appearance." : "使用系统默认外观。",
    "Dyslexia font" : "阅读障碍字体",
    "Enable dyslexia font" : "启用阅读障碍字体",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic是一款免费的字样/字体，这款字体的设计目的是缓解由阅读障碍引起的一些常见阅读错误。",
    "High contrast mode" : "高对比度模式",
    "Enable high contrast mode" : "启用高对比度模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "使用高对比度模式。图像质量会下降，但清晰度会提升。",
    "Light theme" : "浅色主题",
    "Enable the default light theme" : "使用默认浅色主题",
    "The default light appearance." : "默认浅色外观",
    "Legal notice" : "法律声明",
    "Privacy policy" : "隐私政策",
    "Adjust the Nextcloud theme" : "调整 Nextcloud 主题",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "主题使得方便地定制您的实例的外观和体验成为可能。所有用户都可以使用。",
    "Advanced options" : "高级选项",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 ImageMagick，以根据上传的 logo 和颜色自动生成图标。",
    "Name" : "名字",
    "Web link" : "网站链接",
    "a safe home for all your data" : "给您所有的数据一个安全的家",
    "Slogan" : "标语",
    "Color" : "颜色",
    "Logo" : "图标",
    "Upload new logo" : "上传新的图标",
    "Background and login image" : "登录界面与背景图片",
    "Upload new background and login image" : "上传新的登录界面与背景图片",
    "Legal notice link" : "法律声明链接",
    "Privacy policy link" : "隐私政策链接",
    "Header logo" : "顶栏图标",
    "Upload new header logo" : "上传新的顶栏图标",
    "Favicon" : "网站图标",
    "Upload new favicon" : "上传新图标",
    "User settings" : "用户设置",
    "Disable user theming" : "禁用用户自定义主题",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "除了您在此处对实例外观进行的定制外，实例上的用户也可以选择他们自己的背景和主题色。启用此选项可阻止用户自定义外观。",
    "Keyboard shortcuts" : "键盘快捷键",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "某些情况下，键盘快捷键会干扰无障碍浏览工具。该设置可禁用所有键盘快捷键，以便您控制这些工具的焦点。启用该设置将同时禁用所有应用中的快捷键。",
    "Disable all keyboard shortcuts" : "禁用所有键盘快捷键",
    "Background" : "背景",
    "Customization has been disabled by your administrator" : "管理员已禁用自定义功能",
    "Set a custom background" : "选择自定义背景",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "无障碍访问对我们非常重要。 我们遵循网络标准，并进行检查以确保所有内容都可以在没有鼠标或辅助软件（例如屏幕阅读器）的情况下使用。 我们的目标是达到 {guidelines} Web 内容可访问性指南 {linkend} 2.1 中的 AA 级别，并另外通过高对比度主题达到 AAA 级别。",
    "Change color" : "更改颜色",
    "Theme selection is enforced" : "主题由管理员指定",
    "Select a custom color" : "自定义颜色",
    "Reset to default" : "重置为默认设置",
    "Upload" : "上传",
    "Remove background image" : "删除背景图片",
    "Loading preview…" : "正在加载预览...",
    "Admin" : "管理",
    "Error uploading the file" : "上传文件时出错",
    "Name cannot be empty" : "名称不能为空",
    "Pick from Files" : "从文件中挑选",
    "Default image" : "默认图片",
    "Custom color" : "自定义颜色",
    "Plain background" : "纯色背景",
    "Insert from {productName}" : "从 {productName} 插入",
    "Open documentation" : "打开文档",
    "https://…" : "https://…",
    "Upload new login background" : "上传新登录背景",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 Imagemagick，以根据上传的 logo 和颜色自动生成图标。"
},
"nplurals=1; plural=0;");

==> nextcloud-26.0.9.tgz: nextcloud/apps/theming/l10n/zh_CN.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "输入的名称过长",
    "The given web address is too long" : "输入的地址过长",
    "The given web address is not a valid URL" : "提供的 web 地址不是一个合法的 URL",
    "The given legal notice address is too long" : "提供的法律通告地址太长",
    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的 URL",
    "The given privacy policy address is too long" : "提供的隐私政策地址太长",
    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的 URL",
    "The given slogan is too long" : "输入的标语过长",
    "The given color is invalid" : "提供的颜色无效",
    "Disable-user-theming should be true or false" : "Disable-user-theming 应该是 true 或者 false",
    "Saved" : "已保存",
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超出了 php.ini 中的 upload_max_filesize 的值",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件超过了 HTML 表单中指定的 MAX_FILE_SIZE 指令",
    "The file was only partially uploaded" : "该文件只有部分被上传",
    "No file was uploaded" : "没有文件被上传",
    "Missing a temporary folder" : "缺少临时文件夹",
    "Could not write file to disk" : "无法写入文件到磁盘",
    "A PHP extension stopped the file upload" : "PHP 扩展停止了文件上传。",
    "No file uploaded" : "文件没有上传",
    "Failed to clean up the old administration theming images folder" : "无法清除旧的管理主题图片文件夹",
    "Failed to clean up the old administration image folder" : "无法清除旧的管理图片文件夹",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "你已经在使用一个自定义的主题。主题应用的设置可能会被其覆盖。",
    "Theming" : "主题",
    "Appearance and accessibility" : "外观和可访问性",
    "Dark theme with high contrast mode" : "高对比度深色主题",
    "Enable dark high contrast mode" : "使用高对比度深色模式",
    "Similar to the high contrast mode, but with dark colours." : "类似高对比度模式，但是使用深色色调。",
    "Dark theme" : "深色主题",
    "Enable dark theme" : "启用深色主题",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "降低整体亮度以缓解视疲劳的深色主题。",
    "System default theme" : "系统默认主题",
    "Enable the system default" : "使用系统默认主题",
    "Using the default system appearance." : "使用系统默认外观。",
    "Dyslexia font" : "阅读障碍字体",
    "Enable dyslexia font" : "启用阅读障碍字体",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic 是一款免费的字样/字体，这款字体的设计目的是缓解由阅读障碍引起的一些常见阅读错误。",
    "High contrast mode" : "高对比度模式",
    "Enable high contrast mode" : "启用高对比度模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "使用高对比度模式。图像质量会下降，但清晰度会提升。",
    "Light theme" : "浅色主题",
    "Enable the default light theme" : "使用默认浅色主题",
    "The default light appearance." : "默认浅色外观",
    "Legal notice" : "法律声明",
    "Privacy policy" : "隐私政策",
    "Adjust the Nextcloud theme" : "调整 Nextcloud 主题",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "主题使得方便地定制您的实例的外观和体验成为可能。所有用户都可以使用。",
    "Advanced options" : "高级选项",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 ImageMagick，以根据上传的 logo 和颜色自动生成图标。",
    "Name" : "名字",
    "Web link" : "网站链接",
    "a safe home for all your data" : "给您所有的数据一个安全的家",
    "Slogan" : "标语",
    "Color" : "颜色",
    "Logo" : "图标",
    "Upload new logo" : "上传新的图标",
    "Background and login image" : "登录界面与背景图片",
    "Upload new background and login image" : "上传新的登录界面与背景图片",
    "Legal notice link" : "法律声明链接",
    "Privacy policy link" : "隐私政策链接",
    "Header logo" : "顶栏图标",
    "Upload new header logo" : "上传新的顶栏图标",
    "Favicon" : "网站图标",
    "Upload new favicon" : "上传新图标",
    "User settings" : "用户设置",
    "Disable user theming" : "禁用用户自定义主题",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "除了您在此处对实例外观进行的定制外，实例上的用户也可以选择他们自己的背景和主题色。启用此选项可阻止用户自定义外观。",
    "Background" : "背景",
    "Customization has been disabled by your administrator" : "管理员已禁用自定义功能",
    "Set a custom background" : "选择自定义背景",
    "Keyboard shortcuts" : "键盘快捷键",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "某些情况下，键盘快捷键会干扰无障碍浏览工具。该设置可禁用所有键盘快捷键，以便您控制这些工具的焦点。启用该设置将同时禁用所有应用中的快捷键。",
    "Disable all keyboard shortcuts" : "禁用所有键盘快捷键",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "无障碍访问对我们非常重要。 我们遵循网络标准，并进行检查以确保所有内容都可以在没有鼠标或辅助软件（例如屏幕阅读器）的情况下使用。 我们的目标是达到 {guidelines} Web 内容可访问性指南 {linkend} 2.1 中的 AA 级别，并另外通过高对比度主题达到 AAA 级别。",
    "Move up" : "上移",
    "Move down" : "下移",
    "Custom background" : "自定义背景",
    "Default background" : "默认背景",
    "Change color" : "更改颜色",
    "No background" : "没有背景",
    "Select a background from your files" : "从文件中选择背景",
    "Theme selection is enforced" : "主题由管理员指定",
    "Select a custom color" : "自定义颜色",
    "Reset to default" : "重置为默认设置",
    "Upload" : "上传",
    "Remove background image" : "删除背景图片",
    "Loading preview…" : "正在加载预览 ...",
    "Admin" : "管理",
    "Error uploading the file" : "上传文件时出错",
    "Name cannot be empty" : "名称不能为空",
    "Migrate and clean up admin theming images" : "迁移并管理主题图像",
    "Failed to clean up the old admin theming images folder" : "无法清除旧的管理主题图片文件夹",
    "Pick from Files" : "从文件中挑选",
    "Default image" : "默认图片",
    "Custom color" : "自定义颜色",
    "Plain background" : "纯色背景",
    "Insert from {productName}" : "从 {productName} 插入",
    "Open documentation" : "打开文档",
    "https://…" : "https://…",
    "Upload new login background" : "上传新登录背景",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "即使您可以选择并自定义您的实例，用户仍然可以更改他们的背景和颜色。如果您希望强制执行您的设置，请勾选此复选框。",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 Imagemagick，以根据上传的 logo 和颜色自动生成图标。"
},
"nplurals=1; plural=0;");
